from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="OTMODE",  # Replace with your package name
    version="0.1.0",  # Start with a version number like 0.1.0
    author="Lanks Huidong Su",  # Replace with your name
    author_email="u3010549@conect.hku.hk",  # Replace with your email
    description="OTMODE is a computational framework built on Optimal Transport (OT) theory for improving cell-type annotation accuracy and for identifying differential features across conditions in single-cell multi-omics data.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Eggong/OTMODE",  
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8',  # Minimum Python version supported
    install_requires=["absl-py>=2.1.0",
        "adjustText>=1.3.0",
        "aiohappyeyeballs>=2.4.3",
        "aiohttp>=3.10.10",
        "aiosignal>=1.3.1",
        "anndata>=0.10.9",
        "anndata2ri>=1.3.2",
        "annoy>=1.17.3",
        "anyio>=4.6.2.post1",
        "appnope>=0.1.4",
        "argon2-cffi>=23.1.0",
        "argon2-cffi-bindings>=21.2.0",
        "array_api_compat>=1.9.1",
        "arrow>=1.3.0",
        "asttokens>=2.4.1",
        "async-lru>=2.0.4",
        "attrs>=24.2.0",
        "babel>=2.16.0",
        "bbknn>=1.6.0",
        "beautifulsoup4>=4.12.3",
        "bleach>=6.2.0",
        "Brotli>=1.1.0",
        "cached-property>=1.5.2",
        "celltypist>=1.6.3",
        "certifi>=2024.8.30",
        "cffi>=1.17.1",
        "cfgv>=3.4.0",
        "charset-normalizer>=3.4.0",
        "chex>=0.1.87",
        "click>=8.1.7",
        "colorcet>=3.1.0",
        "comm>=0.2.2",
        "contourpy>=1.3.0",
        "cycler>=0.12.1",
        "cykhash>=2.0.1",
        "Cython>=3.0.12",
        "debugpy>=1.8.8",
        "decorator>=5.1.1",
        "decoupler>=1.8.0",
        "defusedxml>=0.7.1",
        "dill>=0.3.9",
        "distlib>=0.3.9",
        "docrep>=0.3.2",
        "dunamai>=1.23.0",
        "dynamo-release>=1.4.1",
        "entrypoints>=0.4",
        "et_xmlfile>=2.0.0",
        "etils>=1.10.0",
        "exceptiongroup>=1.2.2",
        "executing>=2.1.0",
        "fastjsonschema>=2.20.0",
        "filelock>=3.16.1",
        "flax>=0.10.1",
        "fonttools>=4.54.1",
        "fqdn>=1.5.1",
        "frozenlist>=1.5.0",
        "fsspec>=2024.10.0",
        "get_version>=3.5.5",
        "graphviz>=0.20.3",
        "grpcio>=1.67.1",
        "h11>=0.14.0",
        "h2>=4.1.0",
        "h5py>=3.12.1",
        "harmonypy>=0.0.10",
        "hmmlearn>=0.3.3",
        "hpack>=4.0.0",
        "httpcore>=1.0.6",
        "httpx>=0.27.2",
        "humanize>=4.11.0",
        "hyperframe>=6.0.1",
        "identify>=2.6.3",
        "idna>=3.10",
        "igraph>=0.11.8",
        "imageio>=2.37.0",
        "importlib_metadata>=8.5.0",
        "importlib_resources>=6.4.5",
        "inflect>=7.5.0",
        "ipykernel>=6.29.5",
        "ipython>=8.29.0",
        "isoduration>=20.11.0",
        "jax>=0.4.35",
        "jaxlib>=0.4.35",
        "jedi>=0.19.2",
        "Jinja2>=3.1.4",
        "joblib>=1.4.2",
        "json5>=0.9.28",
        "jsonpointer>=3.0.0",
        "jsonschema>=4.23.0",
        "jsonschema-specifications>=2024.10.1",
        "jupyter_client>=8.6.3",
        "jupyter_core>=5.7.2",
        "jupyter-events>=0.10.0",
        "jupyter-lsp>=2.2.5",
        "jupyter_server>=2.14.2",
        "jupyter_server_terminals>=0.5.3",
        "jupyterlab>=4.2.5",
        "jupyterlab_pygments>=0.3.0",
        "jupyterlab_server>=2.27.3",
        "kaleido>=0.2.1",
        "kiwisolver>=1.4.7",
        "lazy_loader>=0.4",
        "legacy-api-wrap>=1.4",
        "leidenalg>=0.10.2",
        "lightning>=2.4.0",
        "lightning-utilities>=0.11.8",
        "llvmlite>=0.43.0",
        "loompy>=3.0.7",
        "MACS3>=3.0.2",
        "Markdown>=3.7",
        "markdown-it-py>=3.0.0",
        "MarkupSafe>=3.0.2",
        "matplotlib>=3.9.2",
        "matplotlib-inline>=0.1.7",
        "matplotlib-venn>=1.1.1",
        "mdurl>=0.1.2",
        "mistune>=3.0.2",
        "ml_collections>=1.0.0",
        "ml_dtypes>=0.5.0",
        "more-itertools>=10.5.0",
        "mpmath>=1.3.0",
        "msgpack>=1.1.0",
        "mudata>=0.3.1",
        "multidict>=6.1.0",
        "multipledispatch>=1.0.0",
        "multiprocess>=0.70.17",
        "natsort>=8.4.0",
        "nbclient>=0.10.0",
        "nbconvert>=7.16.4",
        "nbformat>=5.10.4",
        "nest_asyncio>=1.6.0",
        "networkx>=3.4.2",
        "nodeenv>=1.9.1",
        "notebook>=7.2.2",
        "notebook_shim>=0.2.4",
        "numba>=0.60.0",
        "numdifftools>=0.9.41",
        "numpy>=1.26.4",
        "numpy-groupies>=0.11.2",
        "numpyro>=0.15.3",
        "omnipath>=1.0.8",
        "openpyxl>=3.1.5",
        "opt_einsum>=3.4.0",
        "optax>=0.2.3",
        "orbax-checkpoint>=0.9.1",
        "overrides>=7.7.0",
        "packaging>=24.1",
        "pandas>=2.2.3",
        "pandocfilters>=1.5.0",
        "parso>=0.8.4",
        "patsy>=1.0.0",
        "pexpect>=4.9.0",
        "pickleshare>=0.7.5",
        "pillow>=11.0.0",
        "pip>=24.3.1",
        "pkgutil_resolve_name>=1.3.10",
        "platformdirs>=4.3.6",
        "plotly>=5.24.1",
        "polars>=1.15.0",
        "pooch>=1.8.2",
        "POT>=0.9.5",
        "pre_commit>=4.0.1",
        "prometheus_client>=0.21.0",
        "prompt_toolkit>=3.0.48",
        "propcache>=0.2.0",
        "protobuf>=5.28.3",
        "psutil>=6.1.0",
        "ptyprocess>=0.7.0",
        "pure_eval>=0.2.3",
        "pyarrow>=18.1.0",
        "pycparser>=2.22",
        "pydeseq2>=0.4.12",
        "pydot>=3.0.4",
        "pyfaidx>=0.7.2.2",
        "Pygments>=2.18.0",
        "pynndescent>=0.5.13",
        "pyobjc-core>=10.3.1",
        "pyobjc-framework-Cocoa>=10.3.1",
        "pyparsing>=3.2.0",
        "pyro-api>=0.1.2",
        "pyro-ppl>=1.9.1",
        "PySocks>=1.7.1",
        "python-dateutil>=2.9.0",
        "python-json-logger>=2.0.7",
        "pytorch-lightning>=2.4.0",
        "pytz>=2024.2",
        "PyYAML>=6.0.2",
        "pyzmq>=26.2.0",
        "referencing>=0.35.1",
        "requests>=2.32.3",
        "rfc3339-validator>=0.1.4",
        "rfc3986-validator>=0.1.1",
        "rich>=13.9.4",
        "rpds-py>=0.21.0",
        "rpy2>=3.5.16",
        "rustworkx>=0.15.1",
        "scanpy>=1.10.3",
        "scikit-image>=0.25.1",
        "scikit-learn>=1.4.2",
        "scipy>=1.14.1",
        "scvi-tools>=1.2.0",
        "seaborn>=0.13.2",
        "Send2Trash>=1.8.3",
        "session-info>=1.0.0",
        "setuptools>=75.3.0",
        "six>=1.16.0",
        "snapatac2>=2.7.1",
        "sniffio>=1.3.1",
        "soupsieve>=2.5",
        "sparse>=0.15.4",
        "stack-data>=0.6.2",
        "statsmodels>=0.14.4",
        "stdlib-list>=0.11.0",
        "sympy>=1.13.1",
        "tenacity>=9.0.0",
        "tensorboard>=2.18.0",
        "tensorboard-data-server>=0.7.2",
        "tensorstore>=0.1.67",
        "terminado>=0.18.1",
        "texttable>=1.7.0",
        "threadpoolctl>=3.5.0",
        "tifffile>=2025.1.10",
        "tinycss2>=1.4.0",
        "tomli>=2.0.2",
        "toolz>=1.0.0",
        "torch==2.5.1",  # Be specific with torch
        "torchmetrics>=1.5.2",
        "tornado>=6.4.1",
        "tqdm>=4.67.0",
        "traitlets>=5.14.3",
        "typeguard>=4.4.1",
        "types-python-dateutil>=2.9.0.20241003",
        "typing_extensions>=4.12.2",
        "typing-utils>=0.1.0",
        "tzdata>=2024.2",
        "tzlocal>=5.2",
        "umap-learn>=0.5.7",
        "uri-template>=1.3.0",
        "urllib3>=2.2.3",
        "virtualenv>=20.28.0",
        "wcwidth>=0.2.13",
        "webcolors>=24.8.0",
        "webencodings>=0.5.1",
        "websocket-client>=1.8.0",
        "Werkzeug>=3.1.3",
        "wheel>=0.45.0",
        "wrapt>=1.17.0",
        "xarray>=2024.10.0",
        "yarl>=1.17.1",
        "zipp>=3.21.0",
        "zstandard>=0.23.0"],
    include_package_data=True,  # Important to include files listed in MANIFEST.in
    license="MIT",
    zip_safe=False,
)
